# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class ProjectTypeAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status', 'name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (('name', 'slug',), 'description',),
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'name', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('name',)}


class ProjectAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status',),
        ('project_type__name__icontains',),
        ('name__icontains', 'organization__name__icontains',),
        ('date_start__gte', 'date_start__lte',),
    )
    list_filter = ('status',)
    date_hierarchy = 'date_start'
    fieldsets = (
        (_('general information'), {
           'fields': (
               'organization', 'project_type', 'name', 'description', 'date_start', 'date_end',
           )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'organization', 'project_type', 'name', 'date_start', 'date_end', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('organization', 'project_type',)


class ProjectNumberAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('year', 'last_onumber',)
    advanced_search_fields = (
         ('year__gte', 'year__lte',),
         ('last_date__gte', 'last_date__lte',),
    )
    list_filter = ()
    date_hierarchy = 'last_date'
    fieldsets = (
        (_('general information'), {
           'fields': ('year', 'last_date', 'last_number',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'year', 'last_date', 'last_number', 'ordering',)
    list_display_links = ('year',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.ProjectType, ProjectTypeAdmin)
admin.site.register(models.Project, ProjectAdmin)
admin.site.register(models.ProjectNumber, ProjectNumberAdmin)
