# -*- coding: utf-8 -*-

from rest_framework import viewsets
from rest_framework.decorators import action

from thx.api.views import ThuxViewMixin
from . import serializers
from ... import models
from apps.role.core.views import ThuxRoleViewSetMixin


# PROJECT TYPE
class ProjectTypeViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.ProjectType.objects.all()
    serializer_class = serializers.ProjectTypeSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'ProjectType{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)


# PROJECT
class ProjectViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Project.objects.all()
    serializer_class = serializers.ProjectSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Project{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)


# PROJECT NUMBER
class ProjectNumberViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.ProjectNumber.objects.all()
    serializer_class = serializers.ProjectNumberSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'ProjectNumber{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)
